==> tarte_au_citron-2.0.0.tar.gz: tarte_au_citron/src/LibraryJsDiscover.php <==
<?php

namespace Drupal\tarte_au_citron;

use Drupal\Component\Serialization\Json;
use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Language\LanguageManagerInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Gathers the services plugins.
 */
class LibraryJsDiscover implements LibraryJsDiscoverInterface {

  use StringTranslationTrait;

  /**
   * The tarte_au_citron cache bin.
   *
   * @var \Drupal\Core\Cache\CacheBackendInterface
   */
  protected $cache;

  /**
   * The module handler.
   *
   * @var \Drupal\Core\Extension\ModuleHandlerInterface
   */
  protected $moduleHandler;

  /**
   * The config object.
   *
   * @var \Drupal\Core\Config\ImmutableConfig|null
   */
  protected $config = NULL;

  /**
   * The services manager.
   *
   * @var \Drupal\tarte_au_citron\ServicesManagerInterface|null
   */
  protected $servicesManager = NULL;

  /**
   * The language manager.
   *
   * @var \Drupal\Core\Language\LanguageManagerInterface
   */
  protected $languageManager;

  /**
   * Constructs a new LibraryJsDiscover object.
   *
   * @param \Drupal\Core\Cache\CacheBackendInterface $cache
   *   Cache backend instance to use.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $moduleHandler
   *   Module handler service.
   * @param \Drupal\tarte_au_citron\ServicesManagerInterface $servicesManager
   *   Module handler service.
   * @param \Drupal\Core\Language\LanguageManagerInterface $languageManager
   *   The language module.
   */
  public function __construct(
    CacheBackendInterface $cache,
    ModuleHandlerInterface $moduleHandler,
    ServicesManagerInterface $servicesManager,
    LanguageManagerInterface $languageManager,
  ) {
    $this->cache = $cache;
    $this->moduleHandler = $moduleHandler;
    $this->servicesManager = $servicesManager;
    $this->languageManager = $languageManager;
  }

  /**
   * {@inheritdoc}
   */
  public function getJsServices() {
    $cid = 'tarte_au_citron:services_js';
    if ($data_cached = $this->cache->get($cid)) {
      $results = $data_cached->data;
    }
    else {
      $content_json_path = DRUPAL_ROOT . '/libraries/tarteaucitron/tarteaucitron.services.js';
      $content_json = file_get_contents($content_json_path);
      preg_match_all('/tarteaucitron\.services\.([^\s]+)\s*=\s*(\{.*\};)/Us', $content_json, $matches);
      $results = [];
      foreach ($matches[1] as $key => $service) {
        $jsonServiceStr = $matches[2][$key];
        $jsonServiceStr = preg_replace('/,\s*("|\')?cookies("|\')?\s*:\s*.*};/Us', '}', $jsonServiceStr);
        $results[$service] = $this->getJsonFromString($jsonServiceStr);
        preg_match_all('/tarteaucitron\.user\.(' . $service . '\w+)/i', $content_json, $matches_params);
        $results[$service]['params'] = array_unique($matches_params[1]);
      }
      $this->cache->set($cid, $results);
    }
    return $results;
  }

  /**
   * Extract the texts.
   *
   * @param array $data
   *   The data.
   * @param array $texts
   *   The texts.
   */
  protected function extractTexts(&$data, $texts) {
    foreach ($texts as $key => $value) {
      if (is_array($value)) {
        $data[$key] = [
          'type' => 'mapping',
          'children' => [],
        ];
        $this->extractTexts($data[$key]['children'], $value);
      }
      else {
        $data[$key] = [
          'type' => 'label',
          'default_value' => $value,
        ];
      }

    }
  }

  /**
   * {@inheritdoc}
   */
  public function getTextsAvailableLanguagesConfig() {
    $cid = 'tarte_au_citron:texts_availables';
    $data_cached = $this->cache->get($cid);
    if (!$data_cached) {
      $content_json_path = DRUPAL_ROOT . '/libraries/tarteaucitron/tarteaucitron.js';
      $content_json = file_get_contents($content_json_path);
      $data = [];
      if (preg_match('/\s*availableLanguages\s*=\s*\'([a-z,\s*]+)\'/i', $content_json, $matches)) {
        $languageString = $matches[1];
        $languageString = preg_replace('/[^a-z,]/i', '', $languageString);
        $data = explode(',', $languageString);
        $availableLanguages = $this->languageManager->getLanguages();

        $data = array_intersect_key($availableLanguages, array_flip($data));
      }

      $this->cache->set($cid, $data);

      return $data;
    }

    return $data_cached->data;
  }

  /**
   * {@inheritdoc}
   */
  public function getTextsConfig() {
    $cid = 'tarte_au_citron:configurations_texts';
    $data_cached = $this->cache->get($cid);
    if (!$data_cached) {
      $content_json_path = DRUPAL_ROOT . '/libraries/tarteaucitron/lang/tarteaucitron.en.js';
      $currentLangId = $this->languageManager->getCurrentLanguage()->getId();
      if (array_key_exists($currentLangId, $this->getTextsAvailableLanguagesConfig())) {
        $content_json_path = DRUPAL_ROOT . '/libraries/tarteaucitron/lang/tarteaucitron.' . $currentLangId . '.js';
      }

      $content_json = file_get_contents($content_json_path);
      $data = [];
      if (preg_match('/tarteaucitron.lang\s*=\s*(\{.*\});/Us', $content_json, $matches)) {
        $this->extractTexts($data, $this->getJsonFromString($matches[1]));
      }

      foreach ($this->servicesManager->getServices(TRUE) as $service) {
        $data['engage-' . $service->getPluginId()] = [
          'type' => 'label',
          'default_value' => $this->t('@name is disabled.', ['@name' => $service->getPluginTitle()], ['langcode' => 'en'])->render(),
        ];
      }

      $this->moduleHandler->alter('tarte_au_citron_texts_config', $data);

      $this->cache->set($cid, $data);

      return $data;
    }

    return $data_cached->data;
  }

  /**
   * {@inheritdoc}
   */
  public function getJsConfig() {
    $cid = 'tarte_au_citron:configurations_js';
    $data_cached = $this->cache->get($cid);
    if (!$data_cached) {
      $content_json_path = DRUPAL_ROOT . '/libraries/tarteaucitron/tarteaucitron.js';
      $content_json = file_get_contents($content_json_path);
      $data = [];
      if (preg_match('/defaults\s*=\s*(\{.*\})/Us', $content_json, $matches)) {
        try {
          $data = $this->getJsonFromString($matches[1]);
          foreach ($data as $key => $value) {
            $data[$key] = [
              'type' => is_bool($value) ? 'boolean' : 'label',
              'default_value' => $value,
            ];
          }
        }
        catch (\Exception $e) {
          // Do nothing, prevent errors.
        }
      }

      if (preg_match_all('/\s*tarteaucitron\.parameters\.([a-z\-_0-9]+)/i', $content_json, $matches)) {
        foreach (array_unique($matches[1]) as $key) {
          if (isset($data[$key])) {
            continue;
          }
          $isBool = mb_strpos($key, 'is') === 0 || mb_strpos($key, 'has') === 0;
          $data[$key] = [
            'type' => $isBool ? 'boolean' : 'label',
            'default_value' => $isBool ? FALSE : '',
          ];
        }
      }

      foreach ($data as $key => $value) {
        if ($value['type'] !== 'label' || !preg_match('/(Url|Link)$/', $key)) {
          continue;
        }
        $data[$key]['isUrl'] = TRUE;
      }

      $this->cache->set($cid, $data);

      return $data;
    }

    return $data_cached->data;
  }

  /**
   * Return Json element from string.
   *
   * @param string $string
   *   The string.
   *
   * @return mixed
   *   The String json decoded.
   */
  protected function getJsonFromString($string) {
    $jsonStr = preg_replace('/\s\s+/', '', $string);
    $jsonStr = preg_replace_callback('/:\s*\'(.*)\',/U', function ($m) {
      return ':"' . str_replace('"', '\\\\\"', $m[1]) . '",';
    }, $jsonStr);
    $jsonStr = preg_replace_callback('/(,|{)\s*(("|\')?([^\'"]+)("|\')?)\s*:/U', function ($m) {
      return $m[1] . '"' . $m[4] . '":';
    }, $jsonStr);
    return Json::decode($jsonStr);
  }

}

==> tarte_au_citron-2.0.1.tar.gz: tarte_au_citron/src/LibraryJsDiscover.php <==
<?php

namespace Drupal\tarte_au_citron;

use Drupal\Component\Serialization\Json;
use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Language\LanguageManagerInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Gathers the services plugins.
 */
class LibraryJsDiscover implements LibraryJsDiscoverInterface {

  use StringTranslationTrait;

  /**
   * The tarte_au_citron cache bin.
   *
   * @var \Drupal\Core\Cache\CacheBackendInterface
   */
  protected $cache;

  /**
   * The module handler.
   *
   * @var \Drupal\Core\Extension\ModuleHandlerInterface
   */
  protected $moduleHandler;

  /**
   * The config object.
   *
   * @var \Drupal\Core\Config\ImmutableConfig|null
   */
  protected $config = NULL;

  /**
   * The services manager.
   *
   * @var \Drupal\tarte_au_citron\ServicesManagerInterface|null
   */
  protected $servicesManager = NULL;

  /**
   * The language manager.
   *
   * @var \Drupal\Core\Language\LanguageManagerInterface
   */
  protected $languageManager;

  /**
   * Constructs a new LibraryJsDiscover object.
   *
   * @param \Drupal\Core\Cache\CacheBackendInterface $cache
   *   Cache backend instance to use.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $moduleHandler
   *   Module handler service.
   * @param \Drupal\tarte_au_citron\ServicesManagerInterface $servicesManager
   *   Module handler service.
   * @param \Drupal\Core\Language\LanguageManagerInterface $languageManager
   *   The language module.
   */
  public function __construct(
    CacheBackendInterface $cache,
    ModuleHandlerInterface $moduleHandler,
    ServicesManagerInterface $servicesManager,
    LanguageManagerInterface $languageManager,
  ) {
    $this->cache = $cache;
    $this->moduleHandler = $moduleHandler;
    $this->servicesManager = $servicesManager;
    $this->languageManager = $languageManager;
  }

  /**
   * {@inheritdoc}
   */
  public function getJsServices() {
    $cid = 'tarte_au_citron:services_js';
    if ($data_cached = $this->cache->get($cid)) {
      $results = $data_cached->data;
    }
    else {
      $content_json_path = DRUPAL_ROOT . '/libraries/tarteaucitron/tarteaucitron.services.js';
      $content_json = file_get_contents($content_json_path);
      preg_match_all('/tarteaucitron\.services\.([^\s]+)\s*=\s*(\{.*\};)/Us', $content_json, $matches);
      $results = [];
      foreach ($matches[1] as $key => $service) {
        $jsonServiceStr = $matches[2][$key];
        $jsonServiceStr = preg_replace('/,\s*("|\')?cookies("|\')?\s*:\s*.*};/Us', '}', $jsonServiceStr);
        $results[$service] = $this->getJsonFromString($jsonServiceStr);
        preg_match_all('/tarteaucitron\.user\.(' . $service . '\w+)/i', $content_json, $matches_params);
        $results[$service]['params'] = array_unique($matches_params[1]);
      }
      $this->cache->set($cid, $results);
    }
    return $results;
  }

  /**
   * Extract the texts.
   *
   * @param array $data
   *   The data.
   * @param array $texts
   *   The texts.
   */
  protected function extractTexts(&$data, $texts) {
    foreach ($texts as $key => $value) {
      if (is_array($value)) {
        $data[$key] = [
          'type' => 'mapping',
          'children' => [],
        ];
        $this->extractTexts($data[$key]['children'], $value);
      }
      else {
        $data[$key] = [
          'type' => 'text',
          'default_value' => $value,
        ];
      }

    }
  }

  /**
   * {@inheritdoc}
   */
  public function getTextsAvailableLanguagesConfig() {
    $cid = 'tarte_au_citron:texts_availables';
    $data_cached = $this->cache->get($cid);
    if (!$data_cached) {
      $content_json_path = DRUPAL_ROOT . '/libraries/tarteaucitron/tarteaucitron.js';
      $content_json = file_get_contents($content_json_path);
      $data = [];
      if (preg_match('/\s*availableLanguages\s*=\s*\'([a-z,\s*]+)\'/i', $content_json, $matches)) {
        $languageString = $matches[1];
        $languageString = preg_replace('/[^a-z,]/i', '', $languageString);
        $data = explode(',', $languageString);
        $availableLanguages = $this->languageManager->getLanguages();

        $data = array_intersect_key($availableLanguages, array_flip($data));
      }

      $this->cache->set($cid, $data);

      return $data;
    }

    return $data_cached->data;
  }

  /**
   * {@inheritdoc}
   */
  public function getTextsConfig() {
    $cid = 'tarte_au_citron:configurations_texts';
    $data_cached = $this->cache->get($cid);
    if (!$data_cached) {
      $content_json_path = DRUPAL_ROOT . '/libraries/tarteaucitron/lang/tarteaucitron.en.js';
      $currentLangId = $this->languageManager->getCurrentLanguage()->getId();
      if (array_key_exists($currentLangId, $this->getTextsAvailableLanguagesConfig())) {
        $content_json_path = DRUPAL_ROOT . '/libraries/tarteaucitron/lang/tarteaucitron.' . $currentLangId . '.js';
      }

      $content_json = file_get_contents($content_json_path);
      $data = [];
      if (preg_match('/tarteaucitron.lang\s*=\s*(\{.*\});/Us', $content_json, $matches)) {
        $this->extractTexts($data, $this->getJsonFromString($matches[1]));
      }

      foreach ($this->servicesManager->getServices(TRUE) as $service) {
        $data['engage-' . $service->getPluginId()] = [
          'type' => 'text',
          'default_value' => $this->t('@name is disabled.', ['@name' => $service->getPluginTitle()], ['langcode' => 'en'])->render(),
        ];
      }

      $this->moduleHandler->alter('tarte_au_citron_texts_config', $data);

      $this->cache->set($cid, $data);

      return $data;
    }

    return $data_cached->data;
  }

  /**
   * {@inheritdoc}
   */
  public function getJsConfig() {
    $cid = 'tarte_au_citron:configurations_js';
    $data_cached = $this->cache->get($cid);
    if (!$data_cached) {
      $content_json_path = DRUPAL_ROOT . '/libraries/tarteaucitron/tarteaucitron.js';
      $content_json = file_get_contents($content_json_path);
      $data = [];
      if (preg_match('/defaults\s*=\s*(\{.*\})/Us', $content_json, $matches)) {
        try {
          $data = $this->getJsonFromString($matches[1]);
          foreach ($data as $key => $value) {
            $data[$key] = [
              'type' => is_bool($value) ? 'boolean' : 'label',
              'default_value' => $value,
            ];
          }
        }
        catch (\Exception $e) {
          // Do nothing, prevent errors.
        }
      }

      if (preg_match_all('/\s*tarteaucitron\.parameters\.([a-z\-_0-9]+)/i', $content_json, $matches)) {
        foreach (array_unique($matches[1]) as $key) {
          if (isset($data[$key]) || $key === 'hasOwnProperty') {
            continue;
          }
          $isBool = mb_strpos($key, 'is') === 0 || mb_strpos($key, 'has') === 0;
          $data[$key] = [
            'type' => $isBool ? 'boolean' : 'label',
            'default_value' => $isBool ? FALSE : '',
          ];
        }
      }

      foreach ($data as $key => $value) {
        if ($value['type'] !== 'label' || !preg_match('/(Url|Link)$/', $key)) {
          continue;
        }
        $data[$key]['isUrl'] = TRUE;
      }

      $this->moduleHandler->alter('tarte_au_citron_config', $data);

      $this->cache->set($cid, $data);

      return $data;
    }

    return $data_cached->data;
  }

  /**
   * Return Json element from string.
   *
   * @param string $string
   *   The string.
   *
   * @return mixed
   *   The String json decoded.
   */
  protected function getJsonFromString($string) {
    $jsonStr = preg_replace('/\s\s+/', '', $string);
    $jsonStr = preg_replace_callback('/:\s*\'(.*)\',/U', function ($m) {
      return ':"' . str_replace('"', '\\\\\"', $m[1]) . '",';
    }, $jsonStr);
    $jsonStr = preg_replace_callback('/(,|{)\s*(("|\')?([^\'"]+)("|\')?)\s*:/U', function ($m) {
      return $m[1] . '"' . $m[4] . '":';
    }, $jsonStr);
    return Json::decode($jsonStr);
  }

}
